==> primefaces-extensions-13.0.8-jakarta.jar: META-INF/resources/primefaces-extensions/clipboard/clipboard.js <==
/*
 clipboard.js v2.0.11
 https://clipboardjs.com/

 Licensed MIT © Zeno Rocha
*/
(function(f,q){"object"===typeof exports&&"object"===typeof module?module.exports=q():"function"===typeof define&&define.amd?define([],q):"object"===typeof exports?exports.ClipboardJS=q():f.ClipboardJS=q()})(this,function(){return function(){function f(g){if(w[g])return w[g].exports;var d=w[g]={exports:{}};q[g](d,d.exports,f);return d.exports}var q={686:function(g,d,c){function k(e){try{return document.execCommand(e)}catch(b){return!1}}function r(e){"@babel/helpers - typeof";r="function"===typeof Symbol&&
"symbol"===typeof Symbol.iterator?function(b){return typeof b}:function(b){return b&&"function"===typeof Symbol&&b.constructor===Symbol&&b!==Symbol.prototype?"symbol":typeof b};return r(e)}function h(e){"@babel/helpers - typeof";h="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(b){return typeof b}:function(b){return b&&"function"===typeof Symbol&&b.constructor===Symbol&&b!==Symbol.prototype?"symbol":typeof b};return h(e)}function n(e,b){for(var l=0;l<b.length;l++){var a=b[l];
a.enumerable=a.enumerable||!1;a.configurable=!0;"value"in a&&(a.writable=!0);Object.defineProperty(e,a.key,a)}}function m(e,b,l){b&&n(e.prototype,b);l&&n(e,l);return e}function p(e,b){if("function"!==typeof b&&null!==b)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(b&&b.prototype,{constructor:{value:e,writable:!0,configurable:!0}});b&&t(e,b)}function t(e,b){t=Object.setPrototypeOf||function(l,a){l.__proto__=a;return l};return t(e,b)}function u(e){var b=
y();return function(){var l=z(e);if(b){var a=z(this).constructor;l=Reflect.construct(l,arguments,a)}else l=l.apply(this,arguments);if(!l||"object"!==h(l)&&"function"!==typeof l){if(void 0===this)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");l=this}return l}}function y(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),
!0}catch(e){return!1}}function z(e){z=Object.setPrototypeOf?Object.getPrototypeOf:function(b){return b.__proto__||Object.getPrototypeOf(b)};return z(e)}function A(e,b){e="data-clipboard-".concat(e);if(b.hasAttribute(e))return b.getAttribute(e)}c.d(d,{"default":function(){return F}});g=c(279);g=c.n(g);d=c(370);var G=c.n(d);d=c(817);var B=c.n(d),D=function(e){e=B()(e);k("cut");return e},E=function(e,b){var l="rtl"===document.documentElement.getAttribute("dir"),a=document.createElement("textarea");a.style.fontSize=
"12pt";a.style.border="0";a.style.padding="0";a.style.margin="0";a.style.position="absolute";a.style[l?"right":"left"]="-9999px";a.style.top="".concat(window.pageYOffset||document.documentElement.scrollTop,"px");a.setAttribute("readonly","");a.value=e;b.container.appendChild(a);e=B()(a);k("copy");a.remove();return e},C=function(e){var b=1<arguments.length&&void 0!==arguments[1]?arguments[1]:{container:document.body};"string"===typeof e?b=E(e,b):e instanceof HTMLInputElement&&!["text","search","url",
"tel","password"].includes(null===e||void 0===e?void 0:e.type)?b=E(e.value,b):(b=B()(e),k("copy"));return b},H=function(){var e=0<arguments.length&&void 0!==arguments[0]?arguments[0]:{},b=e.action;b=void 0===b?"copy":b;var l=e.container,a=e.target;e=e.text;if("copy"!==b&&"cut"!==b)throw Error('Invalid "action" value, use either "copy" or "cut"');if(void 0!==a)if(a&&"object"===r(a)&&1===a.nodeType){if("copy"===b&&a.hasAttribute("disabled"))throw Error('Invalid "target" attribute. Please use "readonly" instead of "disabled" attribute');
if("cut"===b&&(a.hasAttribute("readonly")||a.hasAttribute("disabled")))throw Error('Invalid "target" attribute. You can\'t cut text from elements with "readonly" or "disabled" attributes');}else throw Error('Invalid "target" value, use a valid Element');if(e)return C(e,{container:l});if(a)return"cut"===b?D(a):C(a,{container:l})},F=function(e){function b(a,v){if(!(this instanceof b))throw new TypeError("Cannot call a class as a function");var x=l.call(this);x.resolveOptions(v);x.listenClick(a);return x}
p(b,e);var l=u(b);m(b,[{key:"resolveOptions",value:function(){var a=0<arguments.length&&void 0!==arguments[0]?arguments[0]:{};this.action="function"===typeof a.action?a.action:this.defaultAction;this.target="function"===typeof a.target?a.target:this.defaultTarget;this.text="function"===typeof a.text?a.text:this.defaultText;this.container="object"===h(a.container)?a.container:document.body}},{key:"listenClick",value:function(a){var v=this;this.listener=G()(a,"click",function(x){return v.onClick(x)})}},
{key:"onClick",value:function(a){var v=a.delegateTarget||a.currentTarget;a=this.action(v)||"copy";var x=H({action:a,container:this.container,target:this.target(v),text:this.text(v)});this.emit(x?"success":"error",{action:a,text:x,trigger:v,clearSelection:function(){v&&v.focus();window.getSelection().removeAllRanges()}})}},{key:"defaultAction",value:function(a){return A("action",a)}},{key:"defaultTarget",value:function(a){if(a=A("target",a))return document.querySelector(a)}},{key:"defaultText",value:function(a){return A("text",
a)}},{key:"destroy",value:function(){this.listener.destroy()}}],[{key:"copy",value:function(a){return C(a,1<arguments.length&&void 0!==arguments[1]?arguments[1]:{container:document.body})}},{key:"cut",value:function(a){return D(a)}},{key:"isSupported",value:function(){var a=0<arguments.length&&void 0!==arguments[0]?arguments[0]:["copy","cut"],v=!!document.queryCommandSupported;("string"===typeof a?[a]:a).forEach(function(x){v=v&&!!document.queryCommandSupported(x)});return v}}]);return b}(g())},828:function(g){if("undefined"!==
typeof Element&&!Element.prototype.matches){var d=Element.prototype;d.matches=d.matchesSelector||d.mozMatchesSelector||d.msMatchesSelector||d.oMatchesSelector||d.webkitMatchesSelector}g.exports=function(c,k){for(;c&&9!==c.nodeType;){if("function"===typeof c.matches&&c.matches(k))return c;c=c.parentNode}}},438:function(g,d,c){function k(n,m,p,t,u){var y=r.apply(this,arguments);n.addEventListener(p,y,u);return{destroy:function(){n.removeEventListener(p,y,u)}}}function r(n,m,p,t){return function(u){u.delegateTarget=
h(u.target,m);u.delegateTarget&&t.call(n,u)}}var h=c(828);g.exports=function(n,m,p,t,u){if("function"===typeof n.addEventListener)return k.apply(null,arguments);if("function"===typeof p)return k.bind(null,document).apply(null,arguments);"string"===typeof n&&(n=document.querySelectorAll(n));return Array.prototype.map.call(n,function(y){return k(y,m,p,t,u)})}},879:function(g,d){d.node=function(c){return void 0!==c&&c instanceof HTMLElement&&1===c.nodeType};d.nodeList=function(c){var k=Object.prototype.toString.call(c);
return void 0!==c&&("[object NodeList]"===k||"[object HTMLCollection]"===k)&&"length"in c&&(0===c.length||d.node(c[0]))};d.string=function(c){return"string"===typeof c||c instanceof String};d.fn=function(c){return"[object Function]"===Object.prototype.toString.call(c)}},370:function(g,d,c){function k(m,p,t){m.addEventListener(p,t);return{destroy:function(){m.removeEventListener(p,t)}}}function r(m,p,t){Array.prototype.forEach.call(m,function(u){u.addEventListener(p,t)});return{destroy:function(){Array.prototype.forEach.call(m,
function(u){u.removeEventListener(p,t)})}}}var h=c(879),n=c(438);g.exports=function(m,p,t){if(!m&&!p&&!t)throw Error("Missing required arguments");if(!h.string(p))throw new TypeError("Second argument must be a String");if(!h.fn(t))throw new TypeError("Third argument must be a Function");if(h.node(m))return k(m,p,t);if(h.nodeList(m))return r(m,p,t);if(h.string(m))return n(document.body,m,p,t);throw new TypeError("First argument must be a String, HTMLElement, HTMLCollection, or NodeList");}},817:function(g){g.exports=
function(d){if("SELECT"===d.nodeName)d.focus(),d=d.value;else if("INPUT"===d.nodeName||"TEXTAREA"===d.nodeName){var c=d.hasAttribute("readonly");c||d.setAttribute("readonly","");d.select();d.setSelectionRange(0,d.value.length);c||d.removeAttribute("readonly");d=d.value}else{d.hasAttribute("contenteditable")&&d.focus();c=window.getSelection();var k=document.createRange();k.selectNodeContents(d);c.removeAllRanges();c.addRange(k);d=c.toString()}return d}},279:function(g){function d(){}d.prototype={on:function(c,
k,r){var h=this.e||(this.e={});(h[c]||(h[c]=[])).push({fn:k,ctx:r});return this},once:function(c,k,r){function h(){n.off(c,h);k.apply(r,arguments)}var n=this;h._=k;return this.on(c,h,r)},emit:function(c){var k=[].slice.call(arguments,1),r=((this.e||(this.e={}))[c]||[]).slice(),h=0,n=r.length;for(h;h<n;h++)r[h].fn.apply(r[h].ctx,k);return this},off:function(c,k){var r=this.e||(this.e={}),h=r[c],n=[];if(h&&k)for(var m=0,p=h.length;m<p;m++)h[m].fn!==k&&h[m].fn._!==k&&n.push(h[m]);n.length?r[c]=n:delete r[c];
return this}};g.exports=d;g.exports.TinyEmitter=d}},w={};!function(){f.n=function(g){var d=g&&g.__esModule?function(){return g["default"]}:function(){return g};f.d(d,{a:d});return d}}();!function(){f.d=function(g,d){for(var c in d)f.o(d,c)&&!f.o(g,c)&&Object.defineProperty(g,c,{enumerable:!0,get:d[c]})}}();!function(){f.o=function(g,d){return Object.prototype.hasOwnProperty.call(g,d)}}();return f(686)}().default});
PrimeFaces.widget.ExtClipboard=PrimeFaces.widget.BaseWidget.extend({init:function(f){this._super(f);this.id=f.id;this.cfg=f;this.trigger=PrimeFaces.expressions.SearchExpressionFacade.resolveComponentsAsSelector(this.cfg.trigger);this._applyClipboard(this.trigger,f)},_applyClipboard:function(f,q){this.trigger=f;this.destroy();f={action:function(w){return q.action}};q.target?$.extend(!0,f,{target:function(w){w=PrimeFaces.expressions.SearchExpressionFacade.resolveComponentsAsSelector(q.target)[0].id;
w=w.replace(RegExp(":","g"),"\\:");return document.querySelector("#"+w)}}):q.text&&$.extend(!0,f,{text:function(w){return q.text}});this.clipboard=new ClipboardJS(this.trigger[0],f);this._bindEvents()},_bindEvents:function(){var f=this;this.clipboard.on("success",function(q){f.callBehavior("success",{params:[{name:f.id+"_action",value:q.action},{name:f.id+"_text",value:q.text},{name:f.id+"_trigger",value:q.trigger}]});f.cfg.onSuccess&&f.cfg.onSuccess.call(q)});this.clipboard.on("error",function(q){f.callBehavior("error",
{params:[{name:f.id+"_action",value:q.action},{name:f.id+"_trigger",value:q.trigger}]});f.cfg.onError&&f.cfg.onError.call(q)})},destroy:function(){this.clipboard&&this.clipboard.destroy()}});

==> primefaces-extensions-14.0.16-jakarta.jar: META-INF/resources/primefaces-extensions/clipboard/clipboard.js <==
/*
 clipboard.js v2.0.11
 https://clipboardjs.com/

 Licensed MIT © Zeno Rocha
*/
(function(f,q){"object"===typeof exports&&"object"===typeof module?module.exports=q():"function"===typeof define&&define.amd?define([],q):"object"===typeof exports?exports.ClipboardJS=q():f.ClipboardJS=q()})(this,function(){return function(){function f(g){if(w[g])return w[g].exports;var d=w[g]={exports:{}};q[g](d,d.exports,f);return d.exports}var q={686:function(g,d,c){function k(e){try{return document.execCommand(e)}catch(b){return!1}}function r(e){"@babel/helpers - typeof";r="function"===typeof Symbol&&
"symbol"===typeof Symbol.iterator?function(b){return typeof b}:function(b){return b&&"function"===typeof Symbol&&b.constructor===Symbol&&b!==Symbol.prototype?"symbol":typeof b};return r(e)}function h(e){"@babel/helpers - typeof";h="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(b){return typeof b}:function(b){return b&&"function"===typeof Symbol&&b.constructor===Symbol&&b!==Symbol.prototype?"symbol":typeof b};return h(e)}function n(e,b){for(var l=0;l<b.length;l++){var a=b[l];
a.enumerable=a.enumerable||!1;a.configurable=!0;"value"in a&&(a.writable=!0);Object.defineProperty(e,a.key,a)}}function m(e,b,l){b&&n(e.prototype,b);l&&n(e,l);return e}function p(e,b){if("function"!==typeof b&&null!==b)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(b&&b.prototype,{constructor:{value:e,writable:!0,configurable:!0}});b&&t(e,b)}function t(e,b){t=Object.setPrototypeOf||function(l,a){l.__proto__=a;return l};return t(e,b)}function u(e){var b=
y();return function(){var l=z(e);if(b){var a=z(this).constructor;l=Reflect.construct(l,arguments,a)}else l=l.apply(this,arguments);if(!l||"object"!==h(l)&&"function"!==typeof l){if(void 0===this)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");l=this}return l}}function y(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),
!0}catch(e){return!1}}function z(e){z=Object.setPrototypeOf?Object.getPrototypeOf:function(b){return b.__proto__||Object.getPrototypeOf(b)};return z(e)}function A(e,b){e="data-clipboard-".concat(e);if(b.hasAttribute(e))return b.getAttribute(e)}c.d(d,{"default":function(){return F}});g=c(279);g=c.n(g);d=c(370);var G=c.n(d);d=c(817);var B=c.n(d),D=function(e){e=B()(e);k("cut");return e},E=function(e,b){var l="rtl"===document.documentElement.getAttribute("dir"),a=document.createElement("textarea");a.style.fontSize=
"12pt";a.style.border="0";a.style.padding="0";a.style.margin="0";a.style.position="absolute";a.style[l?"right":"left"]="-9999px";a.style.top="".concat(window.pageYOffset||document.documentElement.scrollTop,"px");a.setAttribute("readonly","");a.value=e;b.container.appendChild(a);e=B()(a);k("copy");a.remove();return e},C=function(e){var b=1<arguments.length&&void 0!==arguments[1]?arguments[1]:{container:document.body};"string"===typeof e?b=E(e,b):e instanceof HTMLInputElement&&!["text","search","url",
"tel","password"].includes(null===e||void 0===e?void 0:e.type)?b=E(e.value,b):(b=B()(e),k("copy"));return b},H=function(){var e=0<arguments.length&&void 0!==arguments[0]?arguments[0]:{},b=e.action;b=void 0===b?"copy":b;var l=e.container,a=e.target;e=e.text;if("copy"!==b&&"cut"!==b)throw Error('Invalid "action" value, use either "copy" or "cut"');if(void 0!==a)if(a&&"object"===r(a)&&1===a.nodeType){if("copy"===b&&a.hasAttribute("disabled"))throw Error('Invalid "target" attribute. Please use "readonly" instead of "disabled" attribute');
if("cut"===b&&(a.hasAttribute("readonly")||a.hasAttribute("disabled")))throw Error('Invalid "target" attribute. You can\'t cut text from elements with "readonly" or "disabled" attributes');}else throw Error('Invalid "target" value, use a valid Element');if(e)return C(e,{container:l});if(a)return"cut"===b?D(a):C(a,{container:l})},F=function(e){function b(a,v){if(!(this instanceof b))throw new TypeError("Cannot call a class as a function");var x=l.call(this);x.resolveOptions(v);x.listenClick(a);return x}
p(b,e);var l=u(b);m(b,[{key:"resolveOptions",value:function(){var a=0<arguments.length&&void 0!==arguments[0]?arguments[0]:{};this.action="function"===typeof a.action?a.action:this.defaultAction;this.target="function"===typeof a.target?a.target:this.defaultTarget;this.text="function"===typeof a.text?a.text:this.defaultText;this.container="object"===h(a.container)?a.container:document.body}},{key:"listenClick",value:function(a){var v=this;this.listener=G()(a,"click",function(x){return v.onClick(x)})}},
{key:"onClick",value:function(a){var v=a.delegateTarget||a.currentTarget;a=this.action(v)||"copy";var x=H({action:a,container:this.container,target:this.target(v),text:this.text(v)});this.emit(x?"success":"error",{action:a,text:x,trigger:v,clearSelection:function(){v&&v.focus();window.getSelection().removeAllRanges()}})}},{key:"defaultAction",value:function(a){return A("action",a)}},{key:"defaultTarget",value:function(a){if(a=A("target",a))return document.querySelector(a)}},{key:"defaultText",value:function(a){return A("text",
a)}},{key:"destroy",value:function(){this.listener.destroy()}}],[{key:"copy",value:function(a){return C(a,1<arguments.length&&void 0!==arguments[1]?arguments[1]:{container:document.body})}},{key:"cut",value:function(a){return D(a)}},{key:"isSupported",value:function(){var a=0<arguments.length&&void 0!==arguments[0]?arguments[0]:["copy","cut"],v=!!document.queryCommandSupported;("string"===typeof a?[a]:a).forEach(function(x){v=v&&!!document.queryCommandSupported(x)});return v}}]);return b}(g())},828:function(g){if("undefined"!==
typeof Element&&!Element.prototype.matches){var d=Element.prototype;d.matches=d.matchesSelector||d.mozMatchesSelector||d.msMatchesSelector||d.oMatchesSelector||d.webkitMatchesSelector}g.exports=function(c,k){for(;c&&9!==c.nodeType;){if("function"===typeof c.matches&&c.matches(k))return c;c=c.parentNode}}},438:function(g,d,c){function k(n,m,p,t,u){var y=r.apply(this,arguments);n.addEventListener(p,y,u);return{destroy:function(){n.removeEventListener(p,y,u)}}}function r(n,m,p,t){return function(u){u.delegateTarget=
h(u.target,m);u.delegateTarget&&t.call(n,u)}}var h=c(828);g.exports=function(n,m,p,t,u){if("function"===typeof n.addEventListener)return k.apply(null,arguments);if("function"===typeof p)return k.bind(null,document).apply(null,arguments);"string"===typeof n&&(n=document.querySelectorAll(n));return Array.prototype.map.call(n,function(y){return k(y,m,p,t,u)})}},879:function(g,d){d.node=function(c){return void 0!==c&&c instanceof HTMLElement&&1===c.nodeType};d.nodeList=function(c){var k=Object.prototype.toString.call(c);
return void 0!==c&&("[object NodeList]"===k||"[object HTMLCollection]"===k)&&"length"in c&&(0===c.length||d.node(c[0]))};d.string=function(c){return"string"===typeof c||c instanceof String};d.fn=function(c){return"[object Function]"===Object.prototype.toString.call(c)}},370:function(g,d,c){function k(m,p,t){m.addEventListener(p,t);return{destroy:function(){m.removeEventListener(p,t)}}}function r(m,p,t){Array.prototype.forEach.call(m,function(u){u.addEventListener(p,t)});return{destroy:function(){Array.prototype.forEach.call(m,
function(u){u.removeEventListener(p,t)})}}}var h=c(879),n=c(438);g.exports=function(m,p,t){if(!m&&!p&&!t)throw Error("Missing required arguments");if(!h.string(p))throw new TypeError("Second argument must be a String");if(!h.fn(t))throw new TypeError("Third argument must be a Function");if(h.node(m))return k(m,p,t);if(h.nodeList(m))return r(m,p,t);if(h.string(m))return n(document.body,m,p,t);throw new TypeError("First argument must be a String, HTMLElement, HTMLCollection, or NodeList");}},817:function(g){g.exports=
function(d){if("SELECT"===d.nodeName)d.focus(),d=d.value;else if("INPUT"===d.nodeName||"TEXTAREA"===d.nodeName){var c=d.hasAttribute("readonly");c||d.setAttribute("readonly","");d.select();d.setSelectionRange(0,d.value.length);c||d.removeAttribute("readonly");d=d.value}else{d.hasAttribute("contenteditable")&&d.focus();c=window.getSelection();var k=document.createRange();k.selectNodeContents(d);c.removeAllRanges();c.addRange(k);d=c.toString()}return d}},279:function(g){function d(){}d.prototype={on:function(c,
k,r){var h=this.e||(this.e={});(h[c]||(h[c]=[])).push({fn:k,ctx:r});return this},once:function(c,k,r){function h(){n.off(c,h);k.apply(r,arguments)}var n=this;h._=k;return this.on(c,h,r)},emit:function(c){var k=[].slice.call(arguments,1),r=((this.e||(this.e={}))[c]||[]).slice(),h=0,n=r.length;for(h;h<n;h++)r[h].fn.apply(r[h].ctx,k);return this},off:function(c,k){var r=this.e||(this.e={}),h=r[c],n=[];if(h&&k)for(var m=0,p=h.length;m<p;m++)h[m].fn!==k&&h[m].fn._!==k&&n.push(h[m]);n.length?r[c]=n:delete r[c];
return this}};g.exports=d;g.exports.TinyEmitter=d}},w={};!function(){f.n=function(g){var d=g&&g.__esModule?function(){return g["default"]}:function(){return g};f.d(d,{a:d});return d}}();!function(){f.d=function(g,d){for(var c in d)f.o(d,c)&&!f.o(g,c)&&Object.defineProperty(g,c,{enumerable:!0,get:d[c]})}}();!function(){f.o=function(g,d){return Object.prototype.hasOwnProperty.call(g,d)}}();return f(686)}().default});
PrimeFaces.widget.ExtClipboard=PrimeFaces.widget.BaseWidget.extend({init:function(f){this._super(f);this.id=f.id;this.cfg=f;this.trigger=PrimeFaces.expressions.SearchExpressionFacade.resolveComponentsAsSelector(this.jq,this.cfg.trigger);this._applyClipboard(this.trigger,f)},refresh:function(f){this._remove();this._super(f)},destroy:function(){this._super();this._remove()},_remove:function(){this.clipboard&&this.clipboard.destroy()},_applyClipboard:function(f,q){this.trigger=f;this.destroy();f={action:function(w){return q.action}};
q.target?$.extend(!0,f,{target:function(w){w=PrimeFaces.expressions.SearchExpressionFacade.resolveComponentsAsSelector(this.jq,q.target)[0].id;w=w.replace(RegExp(":","g"),"\\:");return document.querySelector("#"+w)}}):q.text&&$.extend(!0,f,{text:function(w){return q.text}});this.clipboard=new ClipboardJS(this.trigger[0],f);this._bindEvents()},_bindEvents:function(){var f=this;this.clipboard.on("success",function(q){f.callBehavior("success",{params:[{name:f.id+"_action",value:q.action},{name:f.id+
"_text",value:q.text},{name:f.id+"_trigger",value:q.trigger}]});f.cfg.onSuccess&&f.cfg.onSuccess.call(q)});this.clipboard.on("error",function(q){f.callBehavior("error",{params:[{name:f.id+"_action",value:q.action},{name:f.id+"_trigger",value:q.trigger}]});f.cfg.onError&&f.cfg.onError.call(q)})}});
